<?xml version="1.0"?>
<!DOCTYPE stylesheet [
<!ENTITY nbsp   "&#160;">
<!ENTITY copy   "&#169;">
<!ENTITY laquo  "&#171;">
<!ENTITY euml   "&#235;">
<!ENTITY ecirc  "&#234;">
<!ENTITY eacute "&#233;">
<!ENTITY egrave "&#232;">
<!ENTITY iuml   "&#239;">
]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

	<xsl:output method="xml" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
	            doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
	            encoding="iso-8859-1" />

	<xsl:template match="ent">
		<xsl:value-of disable-output-escaping="yes" select="text()" />
	</xsl:template>

	<xsl:template match="/">
		<html>
		<head>
			<meta http-equiv="content-type" content="text/xml; charset=iso-8859-1" />
			<title>
				<xsl:value-of select="/article/title" />
				<xsl:value-of select="/page/title" />
				:: gvtulder.f2o.org</title>
			<link rel="stylesheet" type="text/css" href="/style.css" media="all" />
			<link rel="stylesheet" type="text/css" href="/ie-scrollbar.css" media="all" />
			<link rel="stylesheet" type="text/css" href="/print.css" media="print" />
			<meta name="keywords" lang="nl-nl" content="gijs van tulder, gvtulder, van tulder, gvtulder.f2o.org, brandpunt, evolt, php, web, internet, imagemagick, gd library, mail filter" />
		</head>
		<body>
			<div id="header"><div>
				Gijs van Tulder
			</div></div>
			<div id="menu"><div>
				<a href="http://gvtulder.f2o.org/">gvtulder.f2o.org</a> ::
				<a href="mailto:gvtulder@gmx.net">gvtulder@gmx.net</a>
			</div></div>
			<div id="body">
				<xsl:choose>
					<xsl:when test="descendant::programlisting">
						<xsl:apply-templates select="page" />
						<xsl:apply-templates select="article" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="page" />
						<xsl:apply-templates select="article" />
					</xsl:otherwise>
				</xsl:choose>

				<div id="footer">
					&copy; 2001-2003 Gijs van Tulder ::
					<a href="http://validator.w3.org/check/referer">Valid XHTML</a> ::
					<a href="http://jigsaw.w3.org/css-validator/validator?uri=http://gvtulder.f2o.org/style.css">Valid CSS</a>
				</div>
			</div>
			<div id="links" class="menu">
				<xsl:apply-templates select="document('arg:/_navigation')/menu" />
				<xsl:apply-templates select="/page/links[not(@extern)]" />
				<xsl:apply-templates select="/page/links[@extern]" />
			</div>
		</body>
		</html>
	</xsl:template>

	<xsl:template match="/page">
		<h1><xsl:apply-templates select="title" /></h1>
		<xsl:apply-templates select="content" />
	</xsl:template>

	<xsl:template match="/article">
		<h1><xsl:apply-templates select="title" /></h1>
		<xsl:apply-templates select="articleinfo" />
		<xsl:apply-templates select="section" />
	</xsl:template>

	<xsl:template match="para">
		<p>
			<xsl:apply-templates />
		</p>
	</xsl:template>

	<xsl:template match="section/title">
		<h2>
			<xsl:apply-templates />
		</h2>
	</xsl:template>
	<xsl:template match="section/section/title">
		<h3>
			<xsl:apply-templates />
		</h3>
	</xsl:template>
	<xsl:template match="section/section/section/title">
		<h4>
			<xsl:apply-templates />
		</h4>
	</xsl:template>

	<xsl:template match="programlisting">
		<pre><xsl:value-of select="." /></pre>
	</xsl:template>

	<xsl:template match="command">
		<code><xsl:value-of select="." /></code>
	</xsl:template>
	<xsl:template match="ulink">
		<a href="{@url}">
			<xsl:apply-templates />
		</a>
	</xsl:template>

	<xsl:template match="table">
		<table>
			<xsl:for-each select="tgroup">
				<xsl:for-each select="thead/row">
				<tr>
					<xsl:for-each select="entry">
						<th>
							<xsl:apply-templates />
						</th>
					</xsl:for-each>
				</tr>
				</xsl:for-each>
				<xsl:for-each select="tbody/row">
				<tr>
					<xsl:for-each select="entry">
						<td>
							<xsl:apply-templates />
						</td>
					</xsl:for-each>
				</tr>
				</xsl:for-each>
			</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template match="orderedlist">
		<ol>
			<xsl:apply-templates />
		</ol>
	</xsl:template>
	<xsl:template match="unorderedlist">
		<ul>
			<xsl:apply-templates />
		</ul>
	</xsl:template>
	<xsl:template match="listitem">
		<li>
			<xsl:apply-templates />
		</li>
	</xsl:template>

	<xsl:template match="emphasis">
		<xsl:choose>
			<xsl:when test="@role='bold'">
				<strong>
					<xsl:apply-templates />
				</strong>
			</xsl:when>
			<xsl:otherwise>
				<em>
					<xsl:apply-templates />
				</em>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="articleinfo">
		<div id="rechts">
			<p>
				<xsl:apply-templates select="publishername" />
				<br />
				<xsl:text>[</xsl:text>
				<xsl:apply-templates select="pubdate" />
				<xsl:text>]</xsl:text>
			</p>
		</div>
	</xsl:template>

	<xsl:template match="sidebar">
		<div id="rechts">
			<xsl:apply-templates />
		</div>
	</xsl:template>

	<xsl:template match="sidebar/title">
		<h2><xsl:apply-templates /></h2>
	</xsl:template>

	<xsl:template match="menu">
		<xsl:apply-templates select="./page[kop]" />
		<ul class="ingeklapt">
			<xsl:for-each select="./page[not(kop)]">
				<xsl:if test="./menu and position() &lt; last()">
					<xsl:attribute name="class">uitgeklapt</xsl:attribute>
				</xsl:if>
			</xsl:for-each>
			<xsl:apply-templates select="./page[not(kop)]" />
		</ul>
	</xsl:template>
	<xsl:template match="menu/page">
		<xsl:choose>
			<xsl:when test="not(kop)">
				<li>
					<xsl:if test="not(../../../../menu) and preceding::menu">
						<xsl:attribute name="class">following</xsl:attribute>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="active">
							<a href="/{name}/" class="active">
								<xsl:if test="menu">
									&#187;
								</xsl:if>
								<xsl:value-of select="title" />
							</a>
						</xsl:when>
						<xsl:otherwise>
							<a href="/{name}/">
								<xsl:if test="menu">
									&#187;
								</xsl:if>
								<xsl:value-of select="title" />
							</a>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="menu" />
				</li>
			</xsl:when>
			<xsl:otherwise>
				<h2>
					<a href="/" class="kop">
						<xsl:value-of select="title" />
					</a>
				</h2>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="/page/links[@extern]">
		<ul class="elders">
			<xsl:choose>
				<xsl:when test="not(title)">
					<li class="kop">naar elders</li>
				</xsl:when>
				<xsl:otherwise>
					<li class="kop">
						<xsl:value-of select="title" />
					</li>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="link" />
		</ul>
	</xsl:template>
	<xsl:template match="/page/links/link[@extern]">
		<li>
			<a href="{url}">
				<xsl:value-of select="title" />
			</a>
		</li>
	</xsl:template>
	<xsl:template match="/page/links[not(@extern)]">
		<ul class="bijdezepagina">
			<li class="kop">bij deze pagina</li>
			<xsl:apply-templates />
		</ul>
	</xsl:template>
	<xsl:template match="/page/links/link[not(@extern)]">
		<li>
			<a href="{url}">
				<xsl:value-of select="title" />
			</a>
		</li>
	</xsl:template>

	<xsl:template match="imageobject[objectinfo]">
		<p class="imagecaption">
			<img src="{imagedata/@fileref}" alt="{objectinfo/abstract/title}" />
			<xsl:choose>
				<xsl:when test="/page/@lang='nl'">
					<strong>Afbeelding <xsl:value-of select="count(preceding::imageobject[objectinfo])+1" /><xsl:text>: </xsl:text></strong>
				</xsl:when>
				<xsl:otherwise>
					<strong>Figure <xsl:value-of select="count(preceding::imageobject[objectinfo])+1" /><xsl:text>: </xsl:text></strong>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:value-of select="objectinfo/title" />
		</p>
	</xsl:template>

	<xsl:template match="imagedata">
		<img src="{@fileref}" alt="{@alt}" />
	</xsl:template>
</xsl:stylesheet>